var gulp = require('gulp'),
    $ = require('gulp-load-plugins')({
      pattern: '*'
    }),
    config = {
      paths: {
        src: './src',
        tmp: './.tmp',
        dist: './dist',
        docs: [
          './.tmp/INSTALL.md',
          './.tmp/README.md'
        ],
        raml: [
          './src/**/*.raml'
        ],
        schema: [
          './src/schema/**/*.json'
        ]
      }
    };

gulp.task('default', function () {
  $.runSequence(
    'clean:tmp',
    'raml:verify',
    'schema:lint',
    'raml:compile',
    'build',
    'copy:docs'
  );
});

gulp.task('clean:tmp', function () {
  $.del(config.paths.tmp);
});

gulp.task('raml:verify', function () {
  gulp.src(config.paths.raml)
    .pipe($.raml())
    .pipe($.raml.reporter('default'));
});

gulp.task('schema:lint', function() {
  gulp.src(config.paths.schema)
    .pipe($.jsonlint())
    .pipe($.jsonlint.reporter());
});

gulp.task('raml:compile', function () {
  gulp.src(config.paths.raml)
    .pipe($.exec('$(npm bin)/raml-to-client <%= file.path %> -o ' + config.paths.tmp + ' -l javascript'));
});

gulp.task('build', function () {
  return gulp.src('./.tmp/index.js')
    .pipe($.uglify())
    .pipe($.rename('sdk.min.js'))
    .pipe(gulp.dest(config.paths.dist));
});

gulp.task('copy:docs', function () {
  gulp.src(config.paths.docs)
    .pipe(gulp.dest('./'));
});